<?php
/**
 * Plugin CISTYLE
 * Copyright (c) Christophe IMBERTI
 * Licence Creative commons by-nc-sa
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}
include_spip('inc/presentation');
include_spip('inc/config');
include_spip('inc/cistyle_commun');

function formulaires_cistyle_style_charger_dist($id_style='',$plugin='',$objet='',$element='',$config_fonc='',$retour='') {
    $valeurs = array();
    $tableau_proprietes_element = array();
    $parametrage_par_fichier = false;
    
    if (!autoriser('configurer configuration')){
        return false;
    }
    
    // Cette fonction, passee en parametres, doit retourner un tableau des proprietes de l'élément (pour le formulaire à géométrie variable)
    // ainsi que leur valeur par défaut ou bien, le cas echeant, d'anciennes valeurs dans spip_meta (pour la compatibilité ascendante)
    $f = charger_fonction($config_fonc, 'inc');
    if ($f){
        $tableau_proprietes_element = $f('valeurs_defaut',$objet,$element);
        $parametrage_par_fichier = $f('parametrage_par_fichier',$objet,$element,$id_style);
    }
    
    $tableau_style = cistyle_lire_style($id_style);
    
    if ($tableau_style){
        
        foreach ($tableau_proprietes_element AS $propriete=>$valeur_defaut){
            // Le formulaire est generique avec des POST qui sont préfixés par "champ_"
            $nom_post = "champ_" . $propriete;
            
            if (isset($tableau_style[$propriete])){
                $valeurs[$nom_post] = $tableau_style[$propriete];
            }
            
            // afficher uniquement les proprietes de l'element
            $valeurs['actif_'.$nom_post] = 'oui';
        }
        
    } else {
        foreach ($tableau_proprietes_element AS $propriete=>$valeur_actuelle){
            // Le formulaire est generique avec des POST qui sont préfixés par "champ_"
            $nom_post = "champ_" . $propriete;
            
            $valeurs[$nom_post] = $valeur_actuelle;
            // afficher uniquement les champs de l'element
            $valeurs['actif_'.$nom_post] = 'oui';
        }
    }
    
    if ($parametrage_par_fichier){
        $valeurs['parametrage_par_fichier'] = 'oui';
    } else {
        $valeurs['parametrage_par_fichier'] = '';
    }
    
    return $valeurs;
}

function formulaires_cistyle_style_verifier_dist($id_style='',$plugin='',$objet='',$element='',$config_fonc='',$retour='') {
    $erreurs = array();
    $tableau_proprietes_element = array();
    
    if (_request('reset')) {
        return $erreurs;
    }
    
    $f = charger_fonction($config_fonc, 'inc');
    if ($f){
        $tableau_proprietes_element = $f('valeurs_defaut',$objet,$element);
    }
    
    $tableau_nom_des_proprietes = cistyle_tableau_nom_des_proprietes();
    
    foreach ($tableau_proprietes_element AS $propriete=>$valeur_defaut){
        // Le formulaire est generique avec des POST qui sont préfixés par "champ_"
        $nom_post = "champ_" . $propriete;
        if (isset($_POST[$nom_post])){
            $valeur_post = _request($nom_post);
            
            if (in_array($propriete,$tableau_nom_des_proprietes)){
                if (!cistyle_verifier_propriete($propriete,$valeur_post)){
                        $erreurs[$nom_post] =  _T('cistyle:valeur_incorrecte');
                }
            }
        }
    }
    
    return $erreurs;
}

function formulaires_cistyle_style_traiter_dist($id_style='',$plugin='',$objet='',$element='',$config_fonc='',$retour='') {
    $res = array();
    $valeurs_actuelles = array();
    $valeurs_futures = array();
    $tableau_proprietes_element = array();
    
    if (_request('reset')) {
        $res['redirect'] = generer_url_ecrire($retour);
        refuser_traiter_formulaire_ajax();
    }

    $f = charger_fonction($config_fonc, 'inc');
    if ($f){
        $tableau_proprietes_element = $f('valeurs_defaut',$objet,$element);
        if ($tableau_proprietes_element){
            $valeurs_actuelles = $tableau_proprietes_element;
        }
    }
    
    if (!_request('reset')) {
        foreach ($tableau_proprietes_element AS $propriete=>$valeur_defaut){
            // Le formulaire est generique avec des POST qui sont préfixés par "champ_"
            $nom_post = "champ_" . $propriete;
            if (isset($_POST[$nom_post])){
                $valeurs_futures[$propriete] = _request($nom_post);
            }
        }

        // Enregistrer
        $id_style = cistyle_style_editer($id_style,$plugin,$objet,$element,$valeurs_futures);
        // Associer le style à l'objet/élément
        if ($id_style AND $objet AND $element){
            if ($f){
                $f('associer',$objet,$element,$id_style);
            }
        }
    }

    if (_request('reset')) {
        if ($id_style){
            sql_delete('spip_cistyle_styles', "id_style='". $id_style."'");
        }
        
        // Dissocier le style de l'objet/élément
        if ($objet AND $element){
            if ($f){
                $f('dissocier',$objet,$element);
            }
        }
    }
    
    $res['message_ok'] = _T('config_info_enregistree');
    $res['redirect'] = generer_url_ecrire($retour);
    
    return $res;
}

?>